package com.shilohmorris.dctm.plugin.model;
import com.shilohmorris.dctm.plugin.parser.Parser;
import com.shilohmorris.dctm.plugin.parser.ConfigurationParser;

import java.io.Serializable;
import java.util.List;
import java.util.ArrayList;

/*
 *
 * ****************************************************************************
 * Copyright 2006 Shiloh Morris                                               *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 * ****************************************************************************
 */

/**
 * <p>A ComponentModel contains all the information and elements
 * that make up a configuration file.  These elements include
 * the name, the config file, source files, jsp file names and
 * thier logical names.</p>
 */
public class ComponentModel implements Serializable {

    private String componentName;
    private String className;
    private String stringsFile;
    private String configFileName;

    private List sourceFilesList = new ArrayList();
    private List jspFileList = new ArrayList();

    // TODO: Replace with factory method creation
    private Parser parser = new ConfigurationParser();


    /**
     * Constructor which builds a component model based on the
     * contents of a string.  This string is retireived from
     * a Webtop configuration file.
     * @param contents of the configuration file
     * @param configFileName name of the configuration file
     */
    public ComponentModel(String contents, String configFileName) {
        try {
            parser.parseConfiguration(contents, this);
            this.configFileName = configFileName;
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Convenience method to add a jsp to the jspFileList
     * @param jsp path and file name
     */
    public void addJsp(JspPage jsp) {
        this.jspFileList.add(jsp);
    }


    public String getComponentName() {
        return componentName;
    }

    public void setComponentName(String componentName) {
        this.componentName = componentName;
    }


    public List getJspFileList() {
        return jspFileList;
    }

    public void setJspFileList(List jspFileList) {
        this.jspFileList = jspFileList;
    }


    public String getClassName() {
        return className;
    }

    public void setClassName(String className) {
        this.className = className;
    }


    public String getStringsFile() {
        return stringsFile;
    }

    public void setStringsFile(String stringsFile) {
        this.stringsFile = stringsFile;
    }

    public List getSourceFilesList() {
        return sourceFilesList;
    }

    public void setSourceFilesList(List sourceFilesList) {
        this.sourceFilesList = sourceFilesList;
    }

    public Parser getParser() {
        return parser;
    }

    public void setParser(Parser parser) {
        this.parser = parser;
    }


    public String getConfigFileName() {
        return configFileName;
    }

    public void setConfigFileName(String configFileName) {
        this.configFileName = configFileName;
    }


    public String toString() {
        return "ComponentModel{" +
                "componentName='" + componentName + '\'' +
                ", className='" + className + '\'' +
                ", stringsFile='" + stringsFile + '\'' +
                ", configFileName='" + configFileName + '\'' +
                ", sourceFilesList=" + sourceFilesList +
                ", jspFileList=" + jspFileList +
                ", parser=" + parser +
                '}';
    }
}
