package com.shilohmorris.dctm.plugin.parser;

import com.shilohmorris.dctm.plugin.model.ComponentModel;
import org.jdom.Element;
import org.jdom.Document;
import org.jdom.input.SAXBuilder;
import org.apache.log4j.Logger;

import java.util.List;
import java.util.Iterator;
import java.util.ArrayList;
import java.io.StringReader;

/*
 *
 * ****************************************************************************
 * Copyright 2006 Shiloh Morris                                               *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 * ****************************************************************************
 */

/**
 * <p>Basic implementation of the parser interface.  Utilizes custom
 * handlers to parse the configuration file.  Future versions will
 * utilize Apache Digester.</p>
 *
 */
public class ConfigurationParser implements Parser {

    /**
     * List of classes implementing ElementHandler which
     * will operate on each of the elements
     */
    private List handlersList = new ArrayList();
    private Logger log = Logger.getLogger(this.getClass());

    /**
     * Populates the values of a ComponentModel object with
     * the contents of a Webtop component configuration file.
     *
     * @param contents of the component configuration file
     * @param model to be populated (pass through variable)
     * @return populated Component Model
     * @throws Exception
     */
    public ComponentModel parseConfiguration(String contents, ComponentModel model)
            throws Exception {

        handlersList.add(new ComponentHandler());
        handlersList.add(new JspPagesHandler());
        handlersList.add(new ClassHandler());
        handlersList.add(new StringsHandler());

        SAXBuilder builder = new SAXBuilder();
        Document doc;
        try {
            doc = builder.build(new StringReader(contents));
            Element root = doc.getRootElement();

            // ensure this is a config file
            recurseElements(root, model);
            
        } catch (Exception e) {
            log.error("Unable to build JDOM doc");
        }

        return model;

    }

    /**
     * Iterate through a set of child elements looking for specific tags
     * who's values will be used to populate the Model object.
     *
     * @param element the current xml element
     * @param model the ComponentModel being created from the handler(s)
     */
    private void recurseElements(Element element, ComponentModel model) {

        // iterate through the handlers allowing them to handle execution
        for(Iterator handlers = handlersList.iterator(); handlers.hasNext();) {
            ElementHandler handler = (ElementHandler) handlers.next();
            handler.handleElement(element, model);
        }

        if( element.getChildren() != null && element.getChildren().size() > 0) {
            for(Iterator kids = element.getChildren().iterator(); kids.hasNext();) {
                Element currentKid = (Element) kids.next();
                recurseElements(currentKid, model);
            }
        }
    }
}
