package com.shilohmorris.dctm.plugin.ui;

import com.intellij.openapi.util.IconLoader;

import javax.swing.*;
import javax.swing.tree.TreeCellRenderer;
import javax.swing.tree.DefaultMutableTreeNode;
import java.awt.*;

/*
 *
 * ****************************************************************************
 * Copyright 2006 Shiloh Morris                                               *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 * ****************************************************************************
 */

/**
 * Customized Renderer for the Component Tree
 *
 * Provides customized icons (stolen from IDEA's default icons)
 * (becuase I am a lame arrrrteeeeest).
 */
public class TreeRenderer extends JLabel implements TreeCellRenderer {


        public Component getTreeCellRendererComponent(JTree tree,
                Object value, boolean sel, boolean expanded, boolean leaf,
                int row, boolean hasFocus) {
            DefaultMutableTreeNode node = (DefaultMutableTreeNode) value;
            TreeNodeItem item = (TreeNodeItem) node.getUserObject();
            String nodeName = item.toString();
            if(sel) {
                setForeground(Color.BLUE);
            } else {
                setForeground(Color.BLACK);
            }

            if( hasFocus()) {
                setBorder(BorderFactory.createLineBorder(Color.BLUE, 1));
            } else {
                setBorder(null);
            }

            setText(nodeName);  // set the text
            if( item.getType().equalsIgnoreCase(TreeNodeItem.COMP_ROOT)) {
                setIcon(IconLoader.getIcon("/_cvs/showAsTree.png"));
            } else if( item.getType().equalsIgnoreCase(TreeNodeItem.CONFIG_FILE )) {
                setIcon(IconLoader.getIcon("/fileTypes/xml.png"));
            } else if( item.getType().equalsIgnoreCase(TreeNodeItem.JAVA_FILE )) {
                setIcon(IconLoader.getIcon("/fileTypes/java.png"));
            } else if( item.getType().equalsIgnoreCase(TreeNodeItem.JSP_FOLDER)) {
                setIcon(IconLoader.getIcon("/nodes/folder.png"));
            } else if( item.getType().equalsIgnoreCase(TreeNodeItem.JSP_FILTER )) {
                setIcon(IconLoader.getIcon("/ant/filter.png"));
            } else if( item.getType().equalsIgnoreCase(TreeNodeItem.JSP_FILE )) {
                setIcon(IconLoader.getIcon("/fileTypes/jsp.png"));
            } else if( item.getType().equalsIgnoreCase(TreeNodeItem.NLSPROPS )) {
                setIcon(IconLoader.getIcon("/fileTypes/properties.png"));
            } else if( item.getType().equalsIgnoreCase(TreeNodeItem.ROOT )) {                 
                setIcon(IconLoader.getIcon("/actions/modul.png"));
            }

            return this;
         }
    }

