package com.shilohmorris.dctm.plugin.utils;

import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.openapi.project.Project;
import com.intellij.psi.PsiManager;
import com.intellij.psi.PsiFile;
import com.intellij.psi.PsiClass;
import com.intellij.psi.PsiElement;
import com.intellij.psi.search.PsiShortNamesCache;
import com.intellij.psi.search.GlobalSearchScope;

/*
 *
 * ****************************************************************************
 * Copyright 2006 Shiloh Morris                                               *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 * ****************************************************************************
 */

/**
 * Plugin helper functions
 */
public class PluginUtils {

       /**
         * Translates a fully qualified class name to a virtual file.  Found
         * on Intellij plugin developer's forum.
         *
         * @param project IDEA Project
         * @param clazz search criteria
         * @return requested Source Virtual File
         */
        public static VirtualFile fqnToSourceFile(Project project,
                                                  String clazz) {
            String fqn = clazz.endsWith(".java")
                    ? clazz.replaceFirst(".java", "")
                    : clazz;

            GlobalSearchScope scope = GlobalSearchScope.allScope(project);
            PsiClass psiClass = PsiManager.getInstance(project).findClass
                    (fqn, scope);
            if (null == psiClass) {
                return null;
            }

            PsiElement psiClassSource = psiClass.getNavigationElement();
            // to avoid viewing the decompiled class
            PsiFile psiFile = psiClassSource.getContainingFile();

            return psiFile.getVirtualFile();
        }


    /**
     * Searches for a given filename from a specified starting point
     *
     * @param root starting point for search
     * @param name filename to search for
     * @return file meeting criteria
     */
    public static VirtualFile findFileIn(VirtualFile root, String name) {
        VirtualFile[] files = root.getChildren();
        for(int i = 0; i < files.length; i++) {
            if(files[i].getName().equals(name)){
                return files[i];
            } else {
                PluginUtils.findFileIn(files[i], name);
            }
        }
        return null;
    }

    /**
     * Specialized search mechanism which allows the caller
     * to search for complete paths within a IDEA project.
     *
     * @param path full path to search for
     * @param project IDEA project
     * @return file meeting criteria
     */
    public static VirtualFile findFromPath(String path, Project project) {
        VirtualFile returnFile = null;

        String delim = "/";
        //we need to get just the fileName
        String fileName = path.substring(path.lastIndexOf(delim) + 1);

        PsiShortNamesCache cache = PsiManager.getInstance(project).getShortNamesCache();
        PsiFile[] files = cache.getFilesByName(fileName);

        for( int i = 0; i < files.length; i++) {
            VirtualFile file = files[i].getVirtualFile();
            String currentPath =file.getPath();

            // compare to the path we have - make sure to shorten it as
            // we may have a subpath

            // number of characters to trim
            int diff = currentPath.length() - path.length();

            if(path.equalsIgnoreCase(currentPath.substring(diff))) {
                returnFile = file;
            }
        }

        return  returnFile;

    }

    public static String translateToUrl(String stringsFile) {
        return stringsFile.replaceAll("\\.", "/");
    }
}
